pkglts\.option\.license package
===============================

Submodules
----------

pkglts\.option\.license\.config module
--------------------------------------

.. automodule:: pkglts.option.license.config
    :members:
    :undoc-members:
    :show-inheritance:

pkglts\.option\.license\.handlers module
----------------------------------------

.. automodule:: pkglts.option.license.handlers
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pkglts.option.license
    :members:
    :undoc-members:
    :show-inheritance:
